#!/bin/bash

# This script installs ICARUS Verilog if $ICARUS_HOME is not set,
#                      Veritool if $VERITOOL_HOME is not set

if [ "x" == "x$ISPRAS_HOME" ]
then
  ISPRAS_HOME=$HOME
  export ISPRAS_HOME=$ISPRAS_HOME
fi

argc=$(( $# ))

for(( i = 0; $i < $argc; i++ ))
do
  case $1 in
    --force )
      FORCE=1
    ;;
    * )
  esac
  shift
done

if [ "x" == "x$ICARUS_HOME" ]
then
  INSTALL_ICARUS=1
  ICARUS_HOME="$ISPRAS_HOME/tools/verilog"
  UPDATE_PROFILE_ICARUS=1
else if [ "x" == "x$FORCE" ]
then
  echo "[WARNING] Environment variable ICARUS_HOME is set. It might point to the fact that Icarus Verilog has been already installed."
  echo "[WARNING] If you want to reinstall it, type parameter --force-install-veritool"
else
  INSTALL_ICARUS=1
fi
fi

if [ "x" == "x$VERITOOL_HOME" ]
then
  INSTALL_VERITOOL=1
  VERITOOL_HOME="$ISPRAS_HOME/tools/veritool"
  UPDATE_PROFILE_VERITOOL=1
else if [ "x" == "x$FORCE" ]
then
  echo "[WARNING] Environment variable VERITOOL_HOME is set. It might point to the fact that Veritool has been already installed."
  echo "[WARNING] If you want to reinstall it, type parameter --force-install-veritool"
else 
  INSTALL_VERITOOL=1
fi
fi

##################
# Icarus Verilog #
##################

if [ "x" != "x$INSTALL_ICARUS" ]
then

  ICARUS_DIR="$HOME/downloads/sources/verilog"
  #ICARUS_HOME="$ISPRAS_HOME/tools/verilog"
  ICARUS_VER="0.9.4"
  mkdir -p "$ICARUS_DIR"
  mkdir -p "$ICARUS_HOME"
  cd "$ICARUS_DIR"
  rm -f *tar.gz*
  wget "http://sourceforge.net/projects/iverilog/files/iverilog/$ICARUS_VER/verilog-$ICARUS_VER.tar.gz"
  tar xf verilog-$ICARUS_VER.tar.gz
  cd verilog-$ICARUS_VER
  ./configure --prefix="$ICARUS_HOME"
  make && make install
  export ICARUS_HOME=$ICARUS_HOME
  if [ "x" != "x$UPDATE_PROFILE_ICARUS" ]
  then
    echo "export ICARUS_HOME=$ICARUS_HOME" >> "$HOME/.profile"
    echo "export ICARUS_HOME=$ICARUS_HOME" >> "$HOME/.bashrc"
  fi
  echo "[OK] Icarus Verilog was installed..."
fi

############
# Veritool #
############

if [ "x" != "x$INSTALL_VERITOOL" ]
then

  VERITOOL_DIR="$HOME/downloads/sources/veritool"
  #VERITOOL_HOME="$ISPRAS_HOME/tools/veritool"
  VERITOOL_VER="0.1-beta-20110420"
  mkdir -p "$VERITOOL_DIR"
  mkdir -p "$VERITOOL_HOME"
  cd "$VERITOOL_DIR"
  rm -f *tar.gz*
  wget "http://forge.ispras.ru/attachments/download/767/veritool-$VERITOOL_VER.tar.gz"
  tar xf veritool-$VERITOOL_VER.tar.gz
  cd "veritool-0.1-beta"
  ./configure --prefix="$VERITOOL_HOME"
  make all && make install
  if [ "x" != "x$UPDATE_PROFILE_VERITOOL" ]
  then
    echo "export VERITOOL_HOME=$VERITOOL_HOME" >> "$HOME/.profile"
    echo "export VERITOOL_HOME=$VERITOOL_HOME" >> "$HOME/.bashrc"
  fi
  echo "[OK] Veritool was installed..."
fi

