#!/bin/bash

basedir=`dirname "$0"`
this=`basename "$0"`

usage () {
   cat <<EOF
Usage:
  $this [options] trace_file [another_trace_file yet_another_trace_file ...]

  Report generator processes UTT2-compatible traces into HTML representation.

  Options:
    --dest=output_directory   - set the output directory. The directory is Reports/Report_\$(current_time) by default
    --non-trace-error         - do not process <error> aspect. This option is disabled by default
    --non-trace-fsm           - do not process <fsm> aspect. This option is disabled by default
    --version | -v            - show a version
    --help | -h               - show this message
EOF
}

argc=$(( $# ))

for(( i = 0; $i < $argc; i++ ))
do
  case $1 in
    --version | -v )
      echo $this 0.1.0
      echo ""
      echo "Copyright 2011 (c) ISPRAS"
      echo "Institute for System Programming of the Russian Academy of Sciences"
      echo "25 A.Solzhenitsyn st. Moscow 109004 Russia"
      echo "http://hardware.ispras.ru"
      echo ""
      exit 0
    ;;
    --help | -h )
      usage
      exit 0
    ;;

    --dest | --dest= )
      echo "--dest option should be followed by a directory name"
      echo ""
      usage
      exit 1
    ;;
    --dest=* )
      value=`echo $1 | sed "s/--dest=//"`
      reportgen_options="$reportgen_options -d $value"
      #mkdir -p $value
    ;;

    --non-trace-error )
      reportgen_options="$reportgen_options -e"
    ;;
    --non-trace-fsm )
      reportgen_options="$reportgen_options -f"
    ;;

    *.utt2 )
      if [ "x" == "x$reportgen_traces" ]
      then
        reportgen_traces="$1"
      else
        reportgen_traces="$reportgen_traces $1"
      fi
    ;;

    * )
      usage
      exit 0
  esac
  shift
done

java -jar $basedir/jars/run.jar $reportgen_options $reportgen_traces

